@@ -77,9 +77,7 @@ sub assertion {
 
   my $assert = $self->SUPER::assertion;
 
-  $assert->constraints->clear;
-
-  $assert->constraint('number', true);
+  $assert->clear->string;
 
   return $assert;
 }
